pub struct ExtractResourcePlugin<R: ExtractResource<F>, F = ()>(/* private fields */);Expand description
Plugin for extracting a resource from the main world to be used in the render world. This plugin will automatically add a system to extract the resource of the corresponding type from the main world and insert it into the render world.
Note:
- The resource to extract must implement the
ExtractResourcetrait. - If the resource already exists in the render world, it will be updated with the new value from the main world. Otherwise, it will be inserted as a new resource in the render world.
- The update will only happen if the resource in the main world has changed, to avoid unnecessary updates and potential performance issues.
- The marker type
Fis only used as a way to bypass the orphan rules.