pub struct MainEntity(/* private fields */);Expand description
Component added on the Render world entities that are synced from the Main World in order to keep track of the corresponding main world entity. It points to the corresponding entity in the main world.
Implementations
Sourceimpl MainEntity
impl MainEntity
Methods from Deref<Target = Entity>
pub const PLACEHOLDER: Entity