RenderEntity

Struct RenderEntity 

pub struct RenderEntity(/* private fields */);
Component added on the Main world entities that are synced to the Render World in order to keep track of the corresponding render world entity. It points to the corresponding entity in the render world.

Implementations

Source

impl RenderEntity

pub fn id(&self) -> Entity

Methods from Deref<Target = Entity>

pub const PLACEHOLDER: Entity