pub struct SyncToRenderWorld;Expand description
Marker component that indicates that its entity needs to be synchronized to the render world.
It is added automatically to entities that have components that implement SyncComponent (see SyncComponentPlugin), and can be added manually to entities that need to be synchronized without any specific component requirements.
See sync for more details.