ExtractResource

Trait ExtractResource 

pub trait ExtractResource<F = ()>: Resource {
    type Source: Resource;

    // Required method
    fn extract(source: &Self::Source) -> Self;
}
Trait for extracting a resource from the main world to be used in the render world. See ExtractResourcePlugin.

Required Associated Types

type Source: Resource

Required Methods

fn extract(source: &Self::Source) -> Self

Extracts the resource from the main world to be used in the render world.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors