SyncComponent

Trait SyncComponent 

pub trait SyncComponent<F = ()>: Component {
    type Target: Bundle<Effect: NoBundleEffect>;
}
Trait that links components from the main world with output components in the render world. It is used by SyncComponentPlugin.

Required Associated Types

type Target: Bundle<Effect: NoBundleEffect>

Describes what components should be removed from the render world if the implementing component is removed.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors